summaryrefslogtreecommitdiff
path: root/gtk2_ardour/editor_drag.h
diff options
context:
space:
mode:
authorCarl Hetherington <carl@carlh.net>2010-05-05 22:09:07 +0000
committerCarl Hetherington <carl@carlh.net>2010-05-05 22:09:07 +0000
commit8c423ea2284289a59e1cd549e7661114fa978ec8 (patch)
tree03ab5461a4603634aa06bb798cd1a4c38af8ce8f /gtk2_ardour/editor_drag.h
parentb092cfc21638e4b89164f36ed708136c6cf9c8e0 (diff)
Small cleanups to dragging code. Fix assertion failure on dragging a regions' parent entry from the region list to the canvas (which may be #2811). Fixes to drags of regions onto and then back off canvas; should fix #3109.
git-svn-id: svn://localhost/ardour2/branches/3.0@7068 d708f5d6-7413-0410-9779-e7cbd77b26cf
Diffstat (limited to 'gtk2_ardour/editor_drag.h')
-rw-r--r--gtk2_ardour/editor_drag.h7
1 files changed, 3 insertions, 4 deletions
diff --git a/gtk2_ardour/editor_drag.h b/gtk2_ardour/editor_drag.h
index d0bd00f5e6..fb5ef3da9e 100644
--- a/gtk2_ardour/editor_drag.h
+++ b/gtk2_ardour/editor_drag.h
@@ -50,14 +50,13 @@ public:
bool motion_handler (GdkEvent *, bool);
void abort ();
- void break_drag ();
void add (Drag *);
void set (Drag *, GdkEvent *, Gdk::Cursor* c = 0);
void start_grab (GdkEvent *);
bool end_grab (GdkEvent *);
bool have_item (ArdourCanvas::Item *) const;
/** @return true if an end drag or break_drag is in progress */
bool ending () const {
return _ending;
}
@@ -84,7 +83,7 @@ public:
private:
Editor* _editor;
std::list<Drag*> _drags;
- bool _ending; ///< true if end_grab or break_drag is in progress, otherwise false
+ bool _ending; ///< true if end_grab or abort is in progress, otherwise false
double _current_pointer_x; ///< trackview x of the current pointer
double _current_pointer_y; ///< trackview y of the current pointer
nframes64_t _current_pointer_frame; ///< frame that the pointer is now at
@@ -108,7 +107,7 @@ public:
void swap_grab (ArdourCanvas::Item *, Gdk::Cursor *, uint32_t);
bool motion_handler (GdkEvent*, bool);
- void break_drag ();
+ void abort ();
nframes64_t adjusted_frame (nframes64_t, GdkEvent const *, bool snap = true) const;
nframes64_t adjusted_current_frame (GdkEvent const *, bool snap = true) const;
@@ -50,14 +50,13 @@ public:
bool end_grab (GdkEvent *);
bool have_item (ArdourCanvas::Item *) const;
- /** @return true if an end drag or break_drag is in progress */
+ /** @return true if an end drag or abort is in progress */
bool ending () const {
return _ending;